;Written by Xiaoming Hu, Penn State, Jan, 2010
; contact yuanfangcan@gmail.com
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRF_contributed.ncl"
begin
;
  files=(/"TS_species2003.txtdoublemoist","TS_species2003.txt4thirdmoist","TS_species2003.txtcontrol","TS_species2003.txt2thirdmoist","TS_species2003.txthalfmoist"/)
  sensitivity_var_value = new((/dimsizes(files)/),float)

  do ifiles = 0 , dimsizes(files)-1
  TS_species = readAsciiTable(files(ifiles),18,"float",1) 
   if (ifiles.eq.0) then 
    data_to_plot=TS_species(:,3:3+dimsizes(files)-1) ; column 3 is O3 
    Time = TS_species(:,0) 
   else
    data_to_plot(:,ifiles) = (/TS_species(:,3)/)
   end if 
   sensitivity_var_value(ifiles) = (/dim_avg(TS_species(:,2))/)  ; average of Qv
  end do ; do ifiles 

 figurename = "TS_species_Box_sensitivity2Qv_ContinentalCase"
  wks = gsn_open_wks("eps",figurename)  ; Open an X11 workstation.

  res1             = True
  res1@vpHeightF             = 0.5
  res1@vpWidthF              = 0.5
  res1@vpXF             = 0.2

  res1@gsnFrame               = False                     ; don't draw yet
  res1@gsnDraw                = False                     ; don't advance frame

  res2             = True
  res3             = True
  res1@trXMaxF = 20 
  res1@trXMinF = 4 
  res2@trXMaxF = 20 
  res2@trXMinF = 4 
;  res1@gsnMaximize = True
;  res1@trXMaxF     = max(lon)    ; Control end of X axis
  res1@gsnPaperOrientation       = "landscape"
;  plot = gsn_csm_xy3(wks,Time,O3,Br_OH,BrO,res1,res2,res3)
  res1@xyLineThicknessF       = 6
  res1@xyLineColor = "red"       ; t
;  res1@tmXBMinorOn = False
  res1@tmXBMode = "Explicit"
  res1@tmXBValues     = ispan(0,24,4)
  res1@tmXBLabels     = ispan(0,24,4)
  res1@tmXBLabelStride =0

  res1@tmYLMinorOn = False
;  res1@tmXTOn = False            ; turn off top   labels
;  res1@tmYROn = False            ; turn off top   labels
  res1@tmXBMajorOutwardLengthF = 0.
  res1@tmXBMinorOutwardLengthF = 0.
  res1@tmYLMajorOutwardLengthF = 0.
  res1@tmYLMinorOutwardLengthF = 0.

  res2@xyLineThicknessF       = 6
  res2@xyLineColors = (/"blue","brown"/)     ; u
  res2@tmYRMinorOn = False
  res3@xyLineColor = "blue"      ; v
  res3@tmYRMinorOn = False
  res3@xyLineThicknessF       = 6
 txres               = True
  res1@tiXAxisFontHeightF= 0.025
  res1@tiYAxisFontHeightF= 0.025
  res1@tmXBLabelFontHeightF = 0.025
  res1@tmYLLabelFontHeightF = 0.025
  res3@tmYRLabelFontHeightF = 0.025
 txres@txFontHeightF = 0.025

;  res1@tiYAxisString    = "~F5~d~F21~[O~B~3~N~]/~F5~d~F21~t, ppbv h~S~-1";"O~B~3~N~, ppbv"
  res1@tiYAxisString    = "O~B~3~N~, ppbv";"O~B~3~N~, ppbv"
  res1@tiMainString     = "Continental BL case"
  res1@tiXAxisString    = "Time of Day, Hour"
  res2@tiYAxisString    = "Br, OH, pptv"
  res2@tiYAxisString    = "BrO, pptv"
  res3@tmYRFormat  = "f"
  res2@tmYRFormat  = "f"
  res3@amOrthogonalPosF = 0.87   ; Move "v" axis line to right a little.
 
  res2@xyDashPatterns = (/16/)     ; u
  res3@xyDashPatterns = (/16,4/)     ; u
  
  res1@xyDashPatterns = (/4,0,16,4,12/)       ; 0 is default (solid)
  res1@xyLineColors = (/"red","green","blue","black","brown","blue"/)
  plot = gsn_csm_xy(wks,Time,transpose(data_to_plot),res1)

;
; Set up resources for a customized legend.
;
  lgres                    = True
  lgres@lgLineColors       = (/"red","green","blue","black","brown","blue"/)
  lgres@lgDashIndexes= (/4,0,16,4,12/)       ; 0 is default (solid)
  lgres@lgItemType         = "Lines"        ; show lines only (default)
  lgres@lgLabelFontHeightF = .11            ; legend label font thickness
  lgres@vpWidthF           = 0.3           ; width of legend (NDC)
  lgres@vpHeightF          = 0.18           ; height of legend (NDC)
  lgres@lgPerimThicknessF  = 2.0            ; thicken the box perimeter
;  lgres@lgMonoDashIndex    = True
;  lgres@lgDashIndex        = 0
  lgres@txFontHeightF = 0.025 
  lgres@lgPerimOn = False
  lgres@lgLineThicknessF       = 5

  labels = "Qv "+flt2string(sensitivity_var_value)+" g kg~S~-1" 
;  print(sensitivity_var_value)
  print(labels)
  nitems = dimsizes(labels)                 ; number of legend items

; Create legend
  lbid = gsn_create_legend(wks,nitems,labels,lgres)

;
; Use gsn_add_annotation to attach this legend to our existing plot.
; This way, if we resize the plot, the legend will stay with the
; plot and be resized automatically.
;
  amres                  = True

;
; Point (0,0) is the dead center of the plot. Point (0,.5) is center,
; flush bottom. Point (0.5,0.5) is flush bottom, flush right.
;
  amres@amJust           = "BottomRight"    ; Use bottom right corner of box
                                            ; for determining its location.
  amres@amParallelPosF   = 0.12              ; Move legend to right
  amres@amOrthogonalPosF = -0.15             ; Move legend down.

  annoid = gsn_add_annotation(plot,lbid,amres)  ; add legend to plot
  draw(plot)
  frame(wks)
  system("convert -trim -resize 100% "+figurename+".eps /nsftor/xhu/public_html/Nicole_O3/"+figurename+".png")
  system("rm "+figurename+".eps ")
;  system("mv "+figurename+".eps /micromet/s1/www/htdocs/datatransfer/1999PacificOcean/"+figurename+".eps")
end
