;Written by Xiaoming Hu, Penn State, July, 2011 
; contact yuanfangcan@gmail.com
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"   
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"   
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRF_contributed.ncl"

begin
  Mean_diurnal_hourly_all = readAsciiTable("Mean_diurnal_hourly_all.txt", 8, "float", 1)

  var_names = (/"Temperature","RelativeHumdity","SolarRadiation","MixingRatio","O3-O3_6am", "O3"/)
  var_names_to_show = (/"Temperature","RH","Radiation","Mixing Ratio","O~B~3~N~-O~B~3~N~@6am~N~", "O~B~3~N~"/)
;  unit_to_show = (/"~S~o~N~C","%","W m~S~-2","g kg~S~-1","ppbv","ppbv"/)
  unit_to_show = (/"K","%","W m~S~-2","g kg~S~-1","ppbv","ppbv"/)
do ivars =  dimsizes(var_names)-1,dimsizes(var_names)-1 ; 

    a4_height = 29.7 ; in centimeters, if my 
    a4_width = 23.0 ; reference is correct 
    cm_per_inch = 2.54 
 
  res1                       = True            ; plot mods desired
  res1@tmYMajorGrid                = True          ; implement x grid
  res1@tmYMajorGridThicknessF      = 1.0           ; 2.0 is default
  res1@tmYMajorGridLineDashPattern = 2             ; select short dash lines
  

  res1@tmYLFormat =  "f" 
  res1@vpHeightF             =0.18
  res1@vpWidthF              = 0.85
  res1@vpXF             = 0.15
;  res1@vpYF              =-0.9

  res1@gsnPaperOrientation       = "portrait"
  res1@gsnMaximize       = True
;  res1@trYMaxF           =   70 
;  res1@trYMinF           =   0 
  res1@gsnPaperMargin    = 0.01
  res1@tiYAxisString         = var_names_to_show(ivars)+", "+unit_to_show(ivars) 
  res1@xyDashPatterns    = (/0,16,0,16,0,4/)       ; 0 is default (solid)
;  res1@xyLineColors           = (/"black","green","blue","Turquoise3","Purple4","Magenta2","red","brown"/)
;  res1@xyMarkLineModes   = (/"MarkLines","MarkLines","MarkLines","MarkLines","MarkLines","MarkLines"   /)
  res1@xyMarkLineModes   = (/"Markers","Markers","Markers","Markers","Markers","Markers"   /)
 res1@xyMarkers         =  (/16,16,16,16,16,16/)                      ; choose type of marker  
; res1@xyMarkerColor     = "Turquoise3"       
 res1@xyLineColors       = (/"red","black","green","blue","Purple4","Turquoise3","Purple4","Magenta2","red","brown"/)
 res1@xyMarkerColors     = (/"red","black","green","blue","Purple4","Turquoise3","Purple4","Magenta2","red","brown"/) ;"black"; "Cyan3"       
 res1@xyMarkerSizeF     = 0.01  
  res1@xyLineThicknessF       = 5 
  res1@pmLegendSide           = "Top"               ; Change location of
  res1@pmLegendParallelPosF   = .68                  ; move units right
  res1@pmLegendWidthF         = 0.4                ; Change width and
  res1@pmLegendHeightF        = 0.18                ; height of legend.
  res1@tiXAxisFuncCode = "~"
;  res1@tmYLMode = "Manual"
;  res1@trYMinF = 294.0 
  res1@tmXBMode = "Explicit"
  res1@tiXAxisString         = "Year "
;  res1@tmYLTickStartF= 294.0
;  res1@tmYLTickEndF  = 304.0
  res1@tmYLTickSpacingF = 2.0
  res1@pmTickMarkDisplayMode = "Always"         ; turn on tickmarks
  res1@tmXTOn = False            ; turn off top   labels
  res1@tmYROn = False            ; turn off right labels
  res1@lgPerimOn = False
  res1@lgLabelFontHeightF = 0.0205
  res1@pmLegendSide           = "Top"               ; Change location of
  res1@pmLegendParallelPosF   = .85                  ; move units right
  res1@pmLegendOrthogonalPosF = -0.07                ; move units down
  res1@pmLegendWidthF         = 0.1                ; Change width and
  res1@pmLegendHeightF        = 0.065                ; height of legend.
  res1@tmYLMinorOn = False 
  res1@pmLegendDisplayMode    = "Always"       ; create a legend
  res1@xyExplicitLegendLabels = (/"Obs","Sim"/)

 figurename = "TS_observed_sim_catYears_"+var_names(ivars)
  wks = gsn_open_wks("eps" ,figurename)          ; eps,pdf,x11,ncgm,eeps
  setvalues wks
;    "wkColorMap"        : "BlAqGrYeOrRevi200"
    "wkForegroundColor" : "Black";"Blue"
;    "wkBackgroundColor" : (/1.,1.,1./)
  end setvalues

;  res1@gsnLeftString          = "Simulated by CACHE" ;+  vars(ivar)  
;  res1@gsnRightString          = "July15-18"

   obs = Mean_diurnal_hourly_all(:,ivars+2) 
   value_to_be_plot = new((/2,dimsizes(obs)/),float) 
   value_to_be_plot(0,:) = (/obs/) 
  do iyear=2003,2011
   sim = readAsciiTable("TS_species"+iyear+".txt", 18, "float", 1)
   value_to_be_plot(1,6+(iyear-2003)*24:16+(iyear-2003)*24) = (/sim(0:10,3)/) 
  end do 
  res1@trXMinF = 0 
  res1@trXMaxF = dimsizes(obs)-1 
  index = ispan(0,24*8,24)
  res1@tmXBValues     = index 
  res1@tmXBLabels     = Mean_diurnal_hourly_all(index,0) 
   plot  = gsn_csm_xy (wks,ispan(0,dimsizes(obs)-1,1),value_to_be_plot,res1) ; create plot

  system("convert -trim -resize 100% "+figurename+".eps /nsftor/xhu/public_html/Nicole_O3/"+figurename+".png")
  system("mv "+figurename+".eps /nsftor/xhu/public_html/Nicole_O3/"+figurename+".eps")
;  system("rm "+figurename+".eps")
  print("finish plotting "+var_names(ivars))
  delete(res1@tmXBValues)
  delete(res1@tmXBLabels)
  delete(obs)
  end do ; ivars
 end 

